Struct ArpPendingEntry
Source struct ArpPendingEntry {
entry: ArpCacheEntry,
packet_queue: Mutex<Vec<Vec<u8>>>,
}
ARP cache entry with packet queue
Packets waiting for this ARP resolution
Formats the value using the given formatter.
Read more
Immutably borrows from an owned value.
Read more
Mutably borrows from an owned value.
Read more
Returns the argument unchanged.
Calls U::from(self).
That is, this conversion is whatever the implementation of
[From]<T> for U chooses to do.
The type returned in the event of a conversion error.
Performs the conversion.
The type returned in the event of a conversion error.
Performs the conversion.